@@ -745,6 +745,7 @@ typedef enum _MT_LOG_ID
     MT_VP_FEATURE_GRAPH_INTERMEIDATE_SURFACE_INFO,
     MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO,
     MT_VP_FEATURE_GRAPH_SURFACE_ALLOCATIONHANDLE,
+    MT_VP_FEATURE_GRAPH_GET_RENDERTARGETTYPE,
     MT_VP_HAL_ID_BASE = 0x02000400,
     MT_VP_HAL_PIPELINE_ADAPTER,
     MT_VP_HAL_PIPELINE_ADAPTER_EXT_ENTRY,
@@ -782,6 +783,7 @@ typedef enum _MT_LOG_ID
     MT_VP_HAL_DESTROY_SURF,
     MT_VP_HAL_MEMORY_FOOTPRINT_EXECUTION_ENTRY,
     MT_VP_HAL_MEMORY_FOOTPRINT_EXECUTION_EXIT,
+    MT_VP_HAL_VEBOXNUM_CHECK,
     MT_VP_MHW_ID_BASE = 0x02002000,
     MT_VP_MHW_VE_SURFSTATE_INPUT,
     MT_VP_MHW_VE_SURFSTATE_OUT,
@@ -811,7 +813,7 @@ typedef enum _MT_LOG_ID
 //!
 typedef enum _MT_PARAM_ID
 {
-    MT_PARAM_ID_BASE    = 0,
+    MT_PARAM_ID_BASE = 0,
     MT_ERROR_CODE,
     MT_COMPONENT,
     MT_SUB_COMPONENT,
@@ -881,6 +883,11 @@ typedef enum _MT_PARAM_ID
     MT_MOS_SYNC_BUSYCTX,
     MT_MOS_SYNC_REQCTX,
     MT_MOS_MM_EXT_RESOURCE_NEED_MAKE_RESIDENT,
+    MT_SYNC_WAIT_LOOPCOUNTER,
+    MT_SYNC_CUR_FENCE_TAG,
+    MT_SYNC_LAST_FENCE_TAG,
+    MT_SYNC_WAIT_BEFORE_SYNC,
+    MT_SYNC_WAIT_MICROSECOND,
     MT_PARAM_ID_CP_BASE  = 0x01000000,
     MT_CP_SESSION_TYPE,
     MT_CP_SESSION_MODE,
@@ -1015,6 +1022,7 @@ typedef enum _MT_PARAM_ID
     MT_VP_HAL_SURF_ALLOC_PARAM_NAME,
     MT_VP_HAL_SURF_ALLOC_PARAM_PEAK_SIZE,
     MT_VP_HAL_SURF_ALLOC_PARAM_TOTAL_SIZE,
+    MT_VP_HAL_VEBOX_NUMBER,
     MT_PARAM_ID_VP_FEATURE_GRAPH_BASE = 0x02001400,
     MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT,
     MT_VP_FEATURE_GRAPH_FILTER_LAYERINDEXES_COUNT,
@@ -1098,6 +1106,7 @@ typedef enum _MT_PARAM_ID
     MT_VP_FEATURE_GRAPH_SURFACE_RCDST_TOP,
     MT_VP_FEATURE_GRAPH_SURFACE_RCDST_RIGHT,
     MT_VP_FEATURE_GRAPH_SURFACE_RCDST_BOTTOM,
+    MT_VP_FEATURE_GRAPH_RENDERTARGETTYPE,
     MT_PARAM_ID_VP_MHW_BASE = 0x02002000,
     MT_VP_MHW_VE_SCALABILITY_EN,
     MT_VP_MHW_VE_SCALABILITY_USE_SFC,
