@@ -288,13 +288,13 @@ typedef enum _MOS_MEDIA_OPERATION
 //!
 typedef enum _MOS_GPU_NODE
 {
-    MOS_GPU_NODE_3D      = I915_EXEC_RENDER,
-    MOS_GPU_NODE_COMPUTE = (5<<0), //To change to compute CS later when linux define the name
-    MOS_GPU_NODE_VE      = I915_EXEC_VEBOX,
-    MOS_GPU_NODE_VIDEO   = I915_EXEC_BSD,
-    MOS_GPU_NODE_VIDEO2  = I915_EXEC_VCS2,
-    MOS_GPU_NODE_BLT     = I915_EXEC_BLT,
-    MOS_GPU_NODE_MAX     = 7//GFX_MAX(I915_EXEC_RENDER, I915_EXEC_VEBOX, I915_EXEC_BSD, I915_EXEC_VCS2, I915_EXEC_BLT) + 1
+    MOS_GPU_NODE_3D      = DRM_EXEC_RENDER,
+    MOS_GPU_NODE_COMPUTE = DRM_EXEC_COMPUTE,
+    MOS_GPU_NODE_VE      = DRM_EXEC_VEBOX,
+    MOS_GPU_NODE_VIDEO   = DRM_EXEC_BSD,
+    MOS_GPU_NODE_VIDEO2  = DRM_EXEC_VCS2,
+    MOS_GPU_NODE_BLT     = DRM_EXEC_BLT,
+    MOS_GPU_NODE_MAX     = 7//GFX_MAX(DRM_EXEC_RENDER, DRM_EXEC_COMPUTE, DRM_EXEC_VEBOX, DRM_EXEC_BSD, DRM_EXEC_VCS2, DRM_EXEC_BLT) + 1
 } MOS_GPU_NODE, *PMOS_GPU_NODE;
 
 //!
