@@ -76,7 +76,9 @@ struct CodechalVdencHevcLaData
         uint32_t encodeHints;
     };
     uint32_t pyramidDeltaQP;
-    uint32_t reserved3[9];
+    uint8_t  adaptive_rounding;
+    uint8_t  miniGopSize;
+    uint32_t reserved3[8];
 };
 
 //!
@@ -263,7 +265,7 @@ public:
     MOS_RESOURCE                            m_vdencLaStatsBuffer;                              //!< VDEnc statistics buffer for lookahead
     MOS_RESOURCE                            m_vdencLaDataBuffer;                               //!< lookahead data buffer, output of lookahead analysis
     MOS_RESOURCE                            m_vdencLaInitDmemBuffer = {};                           //!< VDEnc Lookahead Init DMEM buffer
-    MOS_RESOURCE                            m_vdencLaUpdateDmemBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_LPLA_NUM_OF_PASSES];  //!< VDEnc Lookahead Update DMEM buffer
+    MOS_RESOURCE                            m_vdencLaUpdateDmemBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_LPLA_NUM_OF_PASSES] = {};  //!< VDEnc Lookahead Update DMEM buffer
     MOS_RESOURCE                            m_vdencLaHistoryBuffer = {};                            //!< VDEnc lookahead history buffer
     bool                                    m_lookaheadPass = false;                           //!< Indicate if current pass is lookahead pass or encode pass
     bool                                    m_lookaheadInit = true;                            //!< Lookahead init flag
@@ -837,20 +839,12 @@ public:
         PMHW_BATCH_BUFFER batchBuffer,
         PMHW_VDBOX_HEVC_SLICE_STATE params) override;
 
-    MOS_STATUS PrepareHWMetaData(
-        PMOS_RESOURCE           presMetadataBuffer,
-        PMOS_RESOURCE           presLcuBaseAddressBuffer,
-        PMOS_COMMAND_BUFFER     cmdBuffer) override;
+    MOS_STATUS PrepareHWMetaData(PMOS_COMMAND_BUFFER cmdBuffer);
 
 #if USE_CODECHAL_DEBUG_TOOL
     virtual MOS_STATUS DumpHucBrcInit();
     virtual MOS_STATUS DumpHucBrcUpdate(bool isInput);
     virtual MOS_STATUS DumpVdencOutputs();
-    virtual MOS_STATUS DumpSeqParFile() override;
-    MOS_STATUS PopulateDdiParam(
-        PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS hevcSeqParams,
-        PCODEC_HEVC_ENCODE_PICTURE_PARAMS  hevcPicParams,
-        PCODEC_HEVC_ENCODE_SLICE_PARAMS    hevcSlcParams) override;
 
     //!
     //! \brief  Modify the frame size with fake header size
