@@ -72,10 +72,6 @@
 #define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_MEMORY_ACCESS_ERROR_MASK       (1 << 26)
 #define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_DMEM_ERROR_MASK                (1 << 24)
 
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL                 5158
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_BRC_DLL_PATH                   5159
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL_CUSTOMPATH      5160
-
 #define VP9SWBRCLIB  "VP9BRCDLL.dll"
 
 typedef struct _HUC_AUX_BUFFER
@@ -88,8 +84,7 @@ typedef struct _HUC_AUX_BUFFER
     uint8_t  rsvd3;
     uint32_t RSVD[13];
 } HUC_AUX_BUFFER, *PHUC_AUX_BUFFER;
-#define CODECHAL_ENCODE_VP9_FRAME_HEADER_SIZE                   4096
-#define CODECHAL_ENCODE_VP9_MAX_NAL_UNIT_TYPE                   1   // only support one NAL unit for uncompressed header
+
 #define ENCODE_VP9_8K_PIC_WIDTH     8192
 #define ENCODE_VP9_8K_PIC_HEIGHT    8192
 #define ENCODE_VP9_16K_PIC_WIDTH     16384
@@ -402,7 +397,7 @@ public:
     struct HucBrcBuffers
     {
         MOS_RESOURCE           resBrcHistoryBuffer;
-        MOS_RESOURCE           resBrcConstantDataBuffer;
+        MOS_RESOURCE           resBrcConstantDataBuffer[2]; // 0 == I, 1 == P
         MOS_RESOURCE           resBrcMsdkPakBuffer;
         MOS_RESOURCE           resBrcMbEncCurbeWriteBuffer;
         MOS_RESOURCE           resMbEncAdvancedDsh;
@@ -1719,7 +1714,7 @@ public:
     MOS_SURFACE                                 m_4xMeDistortionBuffer;
 
     // BRC
-    HucBrcBuffers                               m_brcBuffers;
+    HucBrcBuffers                               m_brcBuffers = {};
 
     // DYS
     MHW_KERNEL_STATE                            m_dysKernelState;
@@ -1767,7 +1762,7 @@ public:
     uint16_t                                    m_vdencPictureState2ndLevelBBIndex = 0;
     MOS_RESOURCE                                m_resVdencDysPictureState2NdLevelBatchBuffer;
     MOS_RESOURCE                                m_resVdencBrcInitDmemBuffer;
-    MOS_RESOURCE                                m_resVdencBrcUpdateDmemBuffer[3];
+    MOS_RESOURCE                                m_resVdencBrcUpdateDmemBuffer[3][CODECHAL_VP9_ENCODE_RECYCLED_BUFFER_NUM];
     MOS_RESOURCE                                m_resVdencDataExtensionBuffer;
     CODECHAL_ENCODE_BUFFER                      m_resPakcuLevelStreamoutData;
     CODECHAL_ENCODE_BUFFER                      m_resPakSliceLevelStreamutData;
@@ -1779,6 +1774,8 @@ public:
     uint32_t                                    m_sizeOfSseSrcPixelRowStoreBufferPerLcu = 0;
     PCODECHAL_CMD_INITIALIZER                   m_hucCmdInitializer = nullptr;
 
+    bool                                        m_initBrcConstantDataBuffer = false;
+
 protected:
     //!
     //! \brief    Constructor
@@ -1974,6 +1971,10 @@ public:
         PMOS_RESOURCE brcConstResource,
         uint16_t pictureCodingType);
 
+    PMOS_RESOURCE GetBrcConstantBuffer(
+        PMOS_RESOURCE brcConstResource,
+        uint16_t pictureCodingType);
+
     //!
     //! \brief     Compute VD Encode BRC initQP
     //!
