@@ -96,7 +96,8 @@ BltState_Xe_Hpm::~BltState_Xe_Hpm()
 //!
 MOS_STATUS BltState_Xe_Hpm::Initialize()
 {
-    initialized = true;
+    initialized  = true;
+    m_blokCopyon = true;
     return MOS_STATUS_SUCCESS;
 }
 
@@ -682,14 +683,24 @@ MOS_STATUS BltState_Xe_Hpm::SubmitCMD(
         }
 
         RegisterDwParams.dwData = swctrl.DW0.Value;
-        m_miInterface->AddMiLoadRegisterImmCmd(&cmdBuffer, &RegisterDwParams);
-
-        BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
-            &cmdBuffer,
-            &fastCopyBltParam,
-            srcResDetails.YPlaneOffset.iSurfaceOffset,
-            dstResDetails.YPlaneOffset.iSurfaceOffset));
+        BLT_CHK_STATUS_RETURN(m_miInterface->AddMiLoadRegisterImmCmd(&cmdBuffer, &RegisterDwParams));
 
+        if (m_blokCopyon)
+        {
+            BLT_CHK_STATUS_RETURN(m_bltInterface->AddBlockCopyBlt(
+                &cmdBuffer,
+                &fastCopyBltParam,
+                srcResDetails.YPlaneOffset.iSurfaceOffset,
+                dstResDetails.YPlaneOffset.iSurfaceOffset));
+        }
+        else
+        {
+            BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
+                &cmdBuffer,
+                &fastCopyBltParam,
+                srcResDetails.YPlaneOffset.iSurfaceOffset,
+                dstResDetails.YPlaneOffset.iSurfaceOffset));
+        }
         if (planeNum >= 2)
         {
             BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
@@ -697,30 +708,51 @@ MOS_STATUS BltState_Xe_Hpm::SubmitCMD(
              pBltStateParam->pSrcSurface,
              pBltStateParam->pDstSurface,
              1));
-            BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
-                 &cmdBuffer,
-                 &fastCopyBltParam,
-                 srcResDetails.UPlaneOffset.iSurfaceOffset,
-                 dstResDetails.UPlaneOffset.iSurfaceOffset));
-
-              if (planeNum == 3)
-              {
-                  BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
-                      &fastCopyBltParam,
-                      pBltStateParam->pSrcSurface,
-                      pBltStateParam->pDstSurface,
-                      2));
-                  BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
-                      &cmdBuffer,
-                      &fastCopyBltParam,
-                      srcResDetails.VPlaneOffset.iSurfaceOffset,
-                      dstResDetails.VPlaneOffset.iSurfaceOffset));
-              }
-              else if (planeNum > 3)
-              {
-                  MCPY_ASSERTMESSAGE("illegal usage");
-                  return MOS_STATUS_INVALID_PARAMETER;
-              }
+            if (m_blokCopyon)
+            {
+                BLT_CHK_STATUS_RETURN(m_bltInterface->AddBlockCopyBlt(
+                    &cmdBuffer,
+                    &fastCopyBltParam,
+                    srcResDetails.UPlaneOffset.iSurfaceOffset,
+                    dstResDetails.UPlaneOffset.iSurfaceOffset));
+            }
+            else
+            {
+                BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
+                    &cmdBuffer,
+                    &fastCopyBltParam,
+                    srcResDetails.UPlaneOffset.iSurfaceOffset,
+                    dstResDetails.UPlaneOffset.iSurfaceOffset));
+            }
+            if (planeNum == 3)
+            {
+                BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
+                    &fastCopyBltParam,
+                    pBltStateParam->pSrcSurface,
+                    pBltStateParam->pDstSurface,
+                    2));
+                if (m_blokCopyon)
+                {
+                    BLT_CHK_STATUS_RETURN(m_bltInterface->AddBlockCopyBlt(
+                        &cmdBuffer,
+                        &fastCopyBltParam,
+                        srcResDetails.VPlaneOffset.iSurfaceOffset,
+                        dstResDetails.VPlaneOffset.iSurfaceOffset));
+                }
+                else
+                {
+                    BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
+                        &cmdBuffer,
+                        &fastCopyBltParam,
+                        srcResDetails.VPlaneOffset.iSurfaceOffset,
+                        dstResDetails.VPlaneOffset.iSurfaceOffset));
+                }
+            }
+            else if(planeNum > 3)
+            {
+                MCPY_ASSERTMESSAGE("illegal usage");
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
          }
 
     }
