@@ -240,7 +240,8 @@ void VpPlatformInterface::AddVpIsaKernelEntryToList(
     const uint32_t *kernelBin,
     uint32_t        kernelBinSize,
     std::string     postfix,
-    DelayLoadedKernelType delayKernelType)
+    DelayLoadedKernelType delayKernelType,
+    uint32_t              payloadOffset)
 {
     VP_FUNC_CALL();
 
@@ -249,6 +250,7 @@ void VpPlatformInterface::AddVpIsaKernelEntryToList(
     tmpEntry.kernelBinSize = kernelBinSize;
     tmpEntry.postfix       = postfix;
     tmpEntry.kernelType    = delayKernelType;
+    tmpEntry.payloadOffset = payloadOffset;
 
     if (delayKernelType == KernelNone)
     {
@@ -327,7 +329,7 @@ MOS_STATUS VpPlatformInterface::InitVpRenderHwCaps()
         // Init CM kernel form VP ISA Kernel Binary List
         for (auto &curKernelEntry : m_vpIsaKernelBinaryList)
         {
-            VP_PUBLIC_CHK_STATUS_RETURN(InitVpCmKernels(curKernelEntry.kernelBin, curKernelEntry.kernelBinSize, curKernelEntry.postfix));
+            VP_PUBLIC_CHK_STATUS_RETURN(InitVpCmKernels(curKernelEntry.kernelBin, curKernelEntry.kernelBinSize, curKernelEntry.postfix, curKernelEntry.payloadOffset));
         }
     }
 
@@ -362,7 +364,8 @@ MOS_STATUS VpPlatformInterface::InitVpNativeAdvKernels(
 MOS_STATUS VpPlatformInterface::InitVpCmKernels(
     const uint32_t *cisaCode,
     uint32_t        cisaCodeSize,
-    std::string     postfix)
+    std::string     postfix,
+    uint32_t        payloadOffset)
 {
     VP_FUNC_CALL();
     VP_RENDER_CHK_NULL_RETURN(cisaCode);
@@ -491,7 +494,8 @@ MOS_STATUS VpPlatformInterface::InitVpCmKernels(
 
             kernelArg.uIndex           = j;
             kernelArg.eArgKind         = (KRN_ARG_KIND)kind;
-            kernelArg.uOffsetInPayload = inputInfo->getOffset() - CM_PAYLOAD_OFFSET;
+            kernelArg.uOffsetInPayload = inputInfo->getOffset() - payloadOffset;
+
             kernelArg.uSize            = inputInfo->getSize();
 
             vpKernel.AddKernelArg(kernelArg);
@@ -556,7 +560,7 @@ MOS_STATUS VpPlatformInterface::InitializeDelayedKernels(DelayLoadedKernelType t
         {
             if (it->kernelType == type)
             {
-                VP_PUBLIC_CHK_STATUS_RETURN(InitVpCmKernels(it->kernelBin, it->kernelBinSize, it->postfix));
+                VP_PUBLIC_CHK_STATUS_RETURN(InitVpCmKernels(it->kernelBin, it->kernelBinSize, it->postfix, it->payloadOffset));
                 m_vpDelayLoadedBinaryList.erase(it);
             }
             else
